import { extends as _extends } from '../_virtual/next-intl.esm.js';
import { useRouter } from 'next/navigation';
import { useMemo } from 'react';
import { COOKIE_LOCALE_NAME } from '../shared/next-intl.esm2.js';
import localizeHref from '../shared/next-intl.esm3.js';

function getCookieValueByName(name) {
  // https://stackoverflow.com/a/15724300/343045
  var value = "; " + document.cookie;
  var parts = value.split("; " + name + "=");

  if (parts.length === 2) {
    var _parts$pop;

    var part = (_parts$pop = parts.pop()) == null ? void 0 : _parts$pop.split(';').shift();
    if (part) return part;
  }

  throw new Error("Unable to find next-intl cookie, have you configured the middleware?");
}

function getCookieLocale() {
  return getCookieValueByName(COOKIE_LOCALE_NAME);
}

function useLocalizedRouter() {
  var router = useRouter();
  return useMemo(function () {
    return _extends({}, router, {
      push: function push(href) {
        return router.push(localizeHref(getCookieLocale(), href));
      },
      replace: function replace(href) {
        return router.replace(localizeHref(getCookieLocale(), href));
      },
      prefetch: function prefetch(href) {
        return router.prefetch(localizeHref(getCookieLocale(), href));
      }
    });
  }, [router]);
}

export { useLocalizedRouter as default };
//# sourceMappingURL=next-intl.esm2.js.map
