import Link from 'next/link';
import React, { forwardRef } from 'react';
import localizeHref from './localizeHref';
export default function createLocalizedLinkComponent(useLocale) {
    /**
     * Wraps `next/link` and prefixes the `href` with the current locale.
     */
    function LocalizedLink({ href, locale, ...rest }, ref) {
        const curLocale = useLocale();
        if (!locale)
            locale = curLocale;
        let localizedHref;
        if (typeof href === 'string') {
            localizedHref = localizeHref(locale, href);
        }
        else {
            localizedHref = { ...href };
            if (href.pathname) {
                localizedHref.pathname = localizeHref(locale, href.pathname);
            }
        }
        return React.createElement(Link, { ref: ref, href: localizedHref, ...rest });
    }
    return forwardRef(LocalizedLink);
}
//# sourceMappingURL=createLocalizedLinkComponent.js.map